# Changelog
11;rgb:0000/0000/0000
This changelog format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
### Added
### Changed
### Deprecated
### Removed
### Fixed
- Fix image URL in `README.md`
### Security

## [0.1.0] - 2025-12-10
### Added
- Initial public release of `swapfont`.
